@@ -554,7 +554,7 @@ class RPC:
                                 params_data += param['key'] + '=' + \
                                     parse.quote(param['defaultValue'])
                         m_count += 1
-                        if m_count < len(kwargs):
+                        if m_count < len(m_params):
                             params_data += "&"
                     else:
                         m_uri= m_uri.replace("{pk}", parse.quote(
