@@ -123,11 +123,11 @@ class perACL:
                 if not debug:
                     if self._platformKey:
                         self._platformKey += "."
-                        self._platformKey= self._platformKey.upper()
+                        self._platformKey = self._platformKey.upper()
                     if premissionKey:
-                        _handleName = self._platformKey + premissionKey.upper()
+                        _eventKey = self._platformKey + premissionKey.upper()
                     else:
-                        _handleName = self._platformKey + \
+                        _eventKey = self._platformKey + \
                             func.__qualname__.replace('.', '_').upper()
                     params_instance = None
                     for k in args:
@@ -140,12 +140,12 @@ class perACL:
                                 params_instance = v
                                 break
                     if not params_instance:
-                        return Response("can found context.", status=415)
+                        return Response("can found context.", status=500)
                     if isinstance(params_instance, Request):
                         if self._tokenKey in params_instance._request.headers:
                             token = params_instance._request.headers[self._tokenKey]
                         else:
-                            return Response("http headers can not found '%s' key." % self._tokenKey, status=415)
+                            return Response("http headers can not found '%s' key." % self._tokenKey, status=500)
                     elif isinstance(params_instance, dict):
                         token = params_instance[self._tokenKey]
                     elif isinstance(params_instance, (int, str, float)):
@@ -155,18 +155,18 @@ class perACL:
                     if token:
                         if self._rpc:
                             validate_ret = self._rpc.call(
-                                _handleName, **{"token": token, "event": _handleName})
+                                self._rpc_key, **{"token": token, "event": _eventKey})
                             if validate_ret:
                                 if validate_ret['state'] == 200:
                                     validate_state = True
                                 else:
-                                    return Response("access error.(%s)" % validate_ret['msg'])
+                                    return Response("access error.(%s)" % validate_ret['msg'], status=500)
                             else:
-                                return Response("access http error.")
+                                return Response("access http error.", status=500)
                         else:
-                            return Response("rpc handle is none.", status=404)
+                            return Response("rpc handle is none.", status=500)
                     else:
-                        return Response("token(%s) is None.")
+                        return Response("token(%s) is None.", status=500)
                 if validate_state:
                     ret = func(*args, **kwargs)
                     return ret
